permission.tests.test_decorators package
========================================

Submodules
----------

permission.tests.test_decorators.test_classbase module
------------------------------------------------------

.. automodule:: permission.tests.test_decorators.test_classbase
    :members:
    :undoc-members:
    :show-inheritance:

permission.tests.test_decorators.test_functionbase module
---------------------------------------------------------

.. automodule:: permission.tests.test_decorators.test_functionbase
    :members:
    :undoc-members:
    :show-inheritance:

permission.tests.test_decorators.test_methodbase module
-------------------------------------------------------

.. automodule:: permission.tests.test_decorators.test_methodbase
    :members:
    :undoc-members:
    :show-inheritance:

permission.tests.test_decorators.test_permission_required module
----------------------------------------------------------------

.. automodule:: permission.tests.test_decorators.test_permission_required
    :members:
    :undoc-members:
    :show-inheritance:

permission.tests.test_decorators.utils module
---------------------------------------------

.. automodule:: permission.tests.test_decorators.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: permission.tests.test_decorators
    :members:
    :undoc-members:
    :show-inheritance:
